import { describe, expect, test } from "bun:test";
import EMDY from "../index";

describe(EMDY.parse, () => {
  test("parses markdown content without frontmatter", () => {
    const content = "# this is some markdown";
    const parsed = EMDY.parse(content);
    expect(parsed).toEqual({ content });
    expect(Object.keys(parsed)).toEqual(["content"]);
  });

  test("parses markdown content with custom key", () => {
    const content = "# this is some markdown";
    const parsed = EMDY.parse(content, "mark");
    expect(parsed).toEqual({ mark: content });
    expect(Object.keys(parsed)).toEqual(["mark"]);
  });

  test("parses markdown content with frontmatter", () => {
    const content = `---
some: value
also: true
---
And here is the content
    `.trim();

    const parsed = EMDY.parse(content);
    expect(parsed).toEqual({
      some: "value",
      also: true,
      content: "And here is the content",
    });
  });
});

describe(EMDY.stringify, () => {
  test("stringifies markdown content without frontmatter", () => {
    const obj = {
      content: "This is some markdown",
    };

    const stringified = EMDY.stringify(obj);
    expect(stringified).toEqual("This is some markdown");
  });

  test("uses custom key for markdown content", () => {
    const obj = {
      mark: "This is some markdown",
    };

    const stringified = EMDY.stringify(obj, "mark");
    expect(stringified).toEqual("This is some markdown");
  });

  test("stringifies markdown content with frontmatter", () => {
    const obj = {
      content: "This is some markdown",
      some: "value",
      also: true,
    };

    const stringified = EMDY.stringify(obj);
    expect(stringified).toEqual(
      "---\nsome: value\nalso: true\n---\nThis is some markdown",
    );
  });
});
